# IO & Data API

Loading, saving, and converting spectral data.

::: foodspec.io.loaders

::: foodspec.io.exporters

::: foodspec.io.csv_import

::: foodspec.io.core

::: foodspec.io.text_formats

::: foodspec.io.vendor_formats

::: foodspec.data.loader

::: foodspec.data.libraries

::: foodspec.data.public
